************************************************************************************************************************;
************************************************* Musterprogramm SAS ***************************************************;
 
*** Hinweis: Das Musterprogramm dient Ihnen zur Orientierung bei der Erstellung Ihres Programmcodes. Das Ziel ist    ***;
*** Ihre Outputfiles bestmglich fr die Geheimhaltungsprfung aufzubereiten.                                        ***;
*** Bitte beachten Sie: Dieses Musterprogramm enthlt keine statistikspezifischen Hilfestellungen zur Aufbereitung   ***;
*** und Auswertung der von Ihnen beantragten Daten.                                                                  ***;
                                                                                                                    
************************************************************************************************************************;


*** Dateien komprimieren und Outputausrichtung; 
options nocenter linesize=256 pagesize=90 compress=yes;

*** Makros fr Pfade;
%let datenpfad	=	<Pfad wird im Forschungsdatenzentrum ergnzt>;
%let outputpfad = 	<Pfad wird im Forschungsdatenzentrum ergnzt>;

*** Makros fr Datei- und Outputnamen;
%let dateiname  = <dateiname>;   			/*Dateiname einfgen*/
%let outputname = <outputname>; 			/*Outputname einfgen*/

*** Libname vergeben;
libname daten "&datenpfad";


************************************************************************************************************************;
*** Aufzeichnung des Outputfiles starten;
ods html body = "&outputpfad./&outputname..html";


************************************************************************************************************************;
************************************************************************************************************************;
************************************************************************************************************************;


************************************************************************************************************************;
************************************************************************************************************************;
*** Titel des Projekts: <Frauen und Arbeit in der Bundesrepublik>       
*** Datengrundlage: 	<Mikrozensus 2012>
***
*** Dateiname des Programmcodes: <syntaxname.sas> 
*** erstellt: 			<Datum> 
*** von: 				<Name> 
*** E-Mail: 			<E-Mail-Adresse> 
*** Tel.: 				<Telefonnummer> 
*** 
*** Dateiname des Output-Files: <outputname.html>
*** 
*** 
*** Grundriss des Programms: 
***			<Programm zur Untersuchung von mehrfachen Personenstzen (Check der Datenbasis), 
***			 deskriptive Analysen> 
*** 
***
*** Verwendete Variablen: 
*** Originalvariablen: 
***    <EF1:   		Land der Bundesrepublik 
*** 	EF2:   		Regierungsbezirk 
*** 	EF3S:  		Auswahlbezirks-Nummer 
*** 	EF4S:  		Lfd. Nr. d. Haushalts 
*** 	EF5S:  		Lfd. Nr. d. Person im Haushalt
*** 	EF25:  		Lfd. Nr. d. Familie im Haushalt
*** 	EF30:  		Bevlkerung am Hauptwohnsitz
*** 	EF31:  		Bevlkerung in Privathaushalten
*** 	EF44:  		Alter
*** 	EF46:  		Geschlecht
*** 	EF49:  		Familienstand
*** 	EF310: 		Hchster allgemeiner Schulabschluss
*** 	EF952: 		Standardhochrechnungsfaktor Jahr (Basis: Zensus 2011)>
***
*** 
*** Neu angelegte Variablen in dieser Syntax <syntaxname.sas>: 
***    <verh:       dichotome Variable Verheiratet ja/nein
***     persnr:  	Personennummer
*** 	famnr:   	Familiennummer 
*** 	hhnr:    	Haushaltsnummer 
*** 	nrdiff:  	Differenz Haushaltsnummer - Familiennummer
*** 	piddiff: 	Test einmalige Personennummer>
***
*** Anmerkung: Falls Variablen verwendet werden, die in einer vorherigen Syntax erstellt wurden, 
*** diese bitte in separaten Blcken auflisten.
***
*** Gewichtungsvariable: EF952
***
***
************************************************************************************************************************;
************************************************************************************************************************;


************************************************************************************************************************;
*** I. Datenaufbereitung
************************************************************************************************************************;


*** a. Formate definieren;

proc format;
    value verhlab       1 = 'ja'
	                    0 = 'nein';

	value nrdifflab 	1 = 'Haushaltsnummer und Familiennummer unterschiedlich'
				 		0 = 'Haushaltsnummer und Familiennummer gleich';

	value piddifflab 	1 = 'Personennummer mehrfach' 
						0 = 'Personennummer einfach';
run;


*** b. Datensatz einlesen;
*** Speicher- und laufzeiteffizient die Auswahl der bentigten Variablen und Flle direkt vornehmen;

data work.arbeitsdatei;                                          
	set daten.&dateiname
	(keep = EF1 EF2 EF3S EF4S EF5S EF25 EF30 EF31 EF44 EF46 EF49 EF310 EF952

/* Bevlkerung in Privathaushalten (EF31 = 1) am Ort der Hauptwohnung (EF30 < 3)*/

	where = ((EF31 = 1) & (EF30 < 3)) );


*** c. Generierung dichotome Variable verh, die angibt, ob Person verheiratet ist.; 

    verh = 0;
    if EF49 = 2 then verh = 1;
	

*** d. Generierung Haushalts- und Familiennummer aus EF1, EF2, EF3S, EF4S, EF5S, EF25
*** pers EF1-EF5S
*** hhnr EF1-EF4S
*** famnr EF1-EF4S + EF25;

	persnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + (EF5S*10);
	hhnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000)+(EF4S*1000) + 1;
	famnr = (EF1*10000000000) + (EF2*1000000000) + (EF3S*100000) + (EF4S*1000) + (EF25*1);


*** d. Vorbereitung Test: Haushaltsnummer ungleich Familiennummer;
*** Wenn Familiennummer (famnr) ungleich der Haushaltsnummer (hhnr) dann Differenz 
*** Haushaltsnummer - Familiennummer (nrdiff) gleich 1;

	nrdiff=0;
	if (famnr ~= hhnr) then nrdiff = 1;
run;


*** e. Vorbereitung Test: mehrfache Personennummer
*** Personennummer (persnr) gleich der des Vorgngers dann Personennummertest (piddiff) gleich 1;

proc sort data = work.arbeitsdatei;
	by persnr;
run;

data work.arbeitsdatei;
	set work.arbeitsdatei;
	piddiff = 0; 
	if persnr = LAG(persnr) then piddiff = 1;


*** f. Beschriftung der Variablen und Werte;

	label 		
                verh     = 'Verheiratet'
				hhnr 	 = 'Haushaltsnummer' 
				famnr 	 = 'Familiennummer' 
				persnr	 = 'Personennummer'
				nrdiff	 = 'Differenz Haushaltsnummer - Familiennummer' 
		  		piddiff	 = 'Test einmalig Personennummer';

    format 		
				verh verhlab. 
	       		nrdiff nrdifflab.
	       		piddiff piddifflab.;
run;



************************************************************************************************************************;
*** II. Datenauswertung
************************************************************************************************************************;

*** Fr jedes erzeugte Ergebnis muss angegeben werden, ob es auf Geheimhaltung geprft und freigegeben werden soll 
*** oder ob es lediglich den Prfprozessen der FDZ dient. Diese Angabe kann pauschal in einem Kommentar erfolgen, 
*** beispielweise "Alle erzeugten Auswertungen werden bentigt." oder "Es werden ausschlielich gewichtete 
*** Auswertungen bentigt.", solange die Formulierung eindeutig ist.

*** Output Nr. 1: Haushaltsnummer ungleich Familiennummer;

proc freq data = work.arbeitsdatei;
	title 'Output Nr. 1: Haushaltsnummer ungleich Familiennummer';
	table nrdiff;	
run;


*** Output Nr. 2: Test mehrfache Personennummer;
	
proc freq data = work.arbeitsdatei;
	title 'Output Nr. 2: Mehrfache Personennummer';
	table piddiff;	
run;


************************************************************************************************************************;
*** a. gewichtete Auswertungen ***

*** Fr die Geheimhaltungsprfung ist es erforderlich, bei gewichteten Ausgaben zustzlich
*** auch das ungewichtete Ergebnis mit ausgeben zu lassen.

*** Output Nr. 3a: ungewichtete Hufigkeit des Bundeslandes;

proc freq data = work.arbeitsdatei;
	title 'Output Nr. 3a: ungewichtete Hufigkeit des Bundeslandes';
	table EF1;	
run;


*** Output Nr. 3b: gewichtete Hufigkeit des Bundeslandes;

proc freq data = work.arbeitsdatei;
    weight EF952;
	title 'Output Nr. 3b: gewichtete Hufigkeit des Bundeslandes';
	table EF1;	
run;


*** Output Nr. 4a: ungewichtete Regression mit der abhngigen Variablen Alter (EF44) und 
***                den beiden unabhngigen Variablen Geschlecht (EF46) und Verheiratet (verh);

title 'ungewichtete Regression mit der abhngigen Variablen Alter (EF44) und den beiden unabhngigen 
Variablen Geschlecht (EF46) und Verheiratet (verh)';
proc reg data = work.arbeitsdatei;
	model EF44 = EF46 verh;
run;


*** Output Nr. 4b: gewichtete Regression mit der abhngigen Variablen Alter (EF44) und 
***                den beiden unabhngigen Variablen Geschlecht (EF46) und Verheiratet (verh);

title 'gewichtete Regression mit der abhngigen Variablen Alter (EF44) und den beiden unabhngigen 
Variablen Geschlecht (EF46) und Verheiratet (verh)';
proc reg data = work.arbeitsdatei;
  	weight EF952;
  	model EF44 = EF46 verh;
run;


************************************************************************************************************************;
*** b. Auswertungen mit Filterbedingungen ***

*** Restgren, die sich als Differenz zu "Insgesamt" erschlieen, sind zu vermeiden.
*** Beispiel: Sie erzeugen eine "Insgesamt"-Tabelle und eine Tabelle "Mnnlich".
*** Die Restgre/Differenz ist "Weiblich" und muss mit ausgegeben werden. 

*** Output Nr. 5a-c: Hufigkeit des hchsten allgemeinen Schulabschluss nach Gesamt/mnnlich/weiblich; 

proc freq data = work.arbeitsdatei;
	title 'Output Nr. 5a: Hufigkeit des hchsten allgemeinen Schulabschluss nach Gesamt';
	table EF310;
run;

proc freq data=work.arbeitsdatei;
	title 'Output Nr. 5b: Hufigkeit des hchsten allgemeinen Schulabschluss nach mnnlich';
	table EF310;
	where EF46 = 1;
run;

proc freq data = work.arbeitsdatei;
	title 'Output Nr. 5c: Hufigkeit des hchsten allgemeinen Schulabschluss nach weiblich';
	table EF310;
	where EF46 = 2;
run;


*** Hinweis: Alternativ kann fr diese Art der Auswertung auch eine Kreuztabelle ohne vorherige Fallauswahl 
*** verwendet werden. Durch die Verwendung einer Kreuztabelle werden Restgren direkt vermieden.

	
************************************************************************************************************************;
*** c. Ausgabe deskriptiver Kennzahlen ***

*** Aus Geheimhaltungsgrnden sind Minima und Maxima metrischer Variablen zu unterdrcken.

*** Output Nr. 6: Anzahl, Mittelwert und Standardabweichung des Alters aller ledigen Personen (EF49=1);

title 'Output Nr. 6: Anzahl, Mittelwert und Standardabweichung des Alters aller ledigen Personen (EF49=1)';
proc means data = work.arbeitsdatei n mean std;
	var EF44;
	where EF49 = 1;
run;

*** Hinweis: Bei wirtschaftsstatistischen Daten ist bei der Ausgabe von deskriptiven Kennzahlen fr die Geheimhaltungs-
*** prfung das Maximum, der zweitgrte Wert und die Gesamtsumme der Variablen (z.B. Umsatz, Einknfte) mit auszugeben.

************************************************************************************************************************;
*** d. Auswertungen von Dummy-Variablen ***

*** Zustzlich zum Proc-Means-Befehl ist die Hufigkeitstabelle auszugeben, da die Fallzahl der Merkmalsausprgung 
*** fr die Geheimhaltungsprfung bentigt wird.
 
*** Output Nr. 7a-b: Anzahl, Mittelwert und Standardabweichung des Geschlechts aller ber 65-Jhrigen (EF44 > 65);

title 'Output Nr. 7a: Anzahl, Mittelwert und Standardabweichung des Geschlechts aller ber 65-Jhrigen (EF44 > 65)';
proc means data = work.arbeitsdatei n mean std;
	var EF46;
	where EF44 > 65;
run;

title 'Output Nr. 7b: Hufigkeitsauszhlung des Geschlechts aller ber 65-Jhrigen (EF44 > 65)';
proc freq data = work.arbeitsdatei;
	tables EF46;
	where EF44 > 65;
run;


************************************************************************************************************************;
*** e. Ausgabe von Wertetabellen ***

*** Bei der Erstellung von Wertetabellen ist stets die zugrundeliegende Fallzahl mit anzugeben.

*** Erstellen einer benutzerdefinierten Tabelle mit Anzahl, Mittelwert und gltige Hufigkeit (N) des Alters (EF44) 
*** je Ausprgung Familienstand (EF49).

*** Output Nr. 8: Kreuztabelle Alter und Familienstand;

proc tabulate data = work.arbeitsdatei;
	title 'Output Nr. 8: Kreuztabelle Alter und Familienstand';
	var EF44;
	class EF49; 
	table EF44 * (mean N), EF49;
run;


************************************************************************************************************************;

*** Die vorliegende Mustersyntax stellt ein Beispiel fr eine Erstsyntax dar. Wenn in den folgenden Syntaxen 
*** Auswertungen gemacht werden, die einen inhaltlichen Bezug zu bereits erstellten Ergebnissen haben, sind die 
*** Bezge zu den entsprechenden vorherigen Syntaxen sowohl bei der Datenaufbereitung als auch bei der Auswertung in 
*** einem Kommentar kenntlich zu machen.



************************************************************************************************************************;
*** III. Lschen aller temporren Dateien, sobald sie nicht mehr bentigt werden;
************************************************************************************************************************;

proc datasets library = work nolist;
    delete arbeitsdatei;
run;

************************************************************************************************************************;

ods html close;
