*	------------------------------ M U S T E R P R O G R A M M   S T A T A --------------------------------------------
/*                               
	Hinweis: Das Musterprogramm dient Ihnen zur Orientierung bei der Erstellung Ihres Programmcodes.            	
	Das Ziel ist, Ihre Outputfiles bestmöglich für die Geheimhaltungsprüfung aufzubereiten.                     	
	Bitte beachten Sie: Dieses Musterprogramm enthält keine statistikspezifischen Hilfestellungen zur           	
	Aufbereitung und Auswertung der von Ihnen beantragten Daten.                                                	
	
	Vorab einige grundlegende Punkte zur Arbeit mit Stata im FDZ-Kontext:
	
	- Bitte löschen Sie nicht mehr benötigte Temp- und/oder Arbeitsdateien am Ende Ihres Programmes.					
	
	- Bitte definieren Sie im ersten Block Ihrer do-files Ihre Arbeitsumgebung (z.B. GWAP oder KDFV) 
	  und führen Sie Ihre (ggf. unterschiedlichen) Datensätze ein.	
	
	- Bitte berücksichtigen Sie bei all Ihren Auswertungen die "Basisanforderungen an die Syntax" sowie die
	  "Kriterien zur Zulassung von Output", die Sie in unserer Broschüre finden!
	
	- Bitte legen Sie eine Masterdatei an, sollten Ihre Auswertungen mit Hilfe mehrerer do-files
	  erstellt werden.
	  
	Bitte beachten Sie auch, dass der online-Abruf von ado-Files über die FDZ nicht möglich ist. Wenn Sie
	ado-Files nutzen möchten, stellen Sie uns diese bitte als lokal abzuspeichernde Datei bereit. Ado-Files
	werden nur nach vorheriger Prüfung zugelassen.
*/                                                                                                                    



*	-------------------------------------------------------------------------------------------------------------------
*	----
*	----	Grundeinstellungen
*	----
*	-------------------------------------------------------------------------------------------------------------------

clear all
set more off
* ggf. weiterführende Grundeinstellungen 



*	-------------------------------------------------------------------------------------------------------------------
*	----
*	----	Block I: Arbeitsumgebung definieren
*	----
*	-------------------------------------------------------------------------------------------------------------------

/*
Im FDZ unterscheiden wir grundsätzlich drei Arbeitsumgebungen: 
0. eigene Arbeitsumgebung im Büro/zu Hause
1. kontrollierte Datenfernverarbeitung (KDFV)
2. Gastwissenschaftsarbeitsplatz (GWAP)

Es gibt FDZ-Projekte, die ausschließlich in einer Arbeitsumgebung laufen, z.B. reine GWAP-Projekte.
Es gibt jedoch auch FDZ-Projekte, die in mehreren Arbeitsumgebungen laufen. So können z.B. ausgewählte Datensätze nicht 
im kompletten Umfang an den GWAP gestellt werden (Wirtschaftsdaten, Steuerdaten). Nutzende haben am GWAP lediglich 
eingeschränkten Zugang auf die Daten, können aber Auswertungsprogramme am GWAP erstellen. Diese werden dann von 
FDZ-Mitarbeiter/-innen über die KDFV auf den Originaldaten laufen gelassen. Dazu ist eine Anpassung der Pfadangaben 
notwendig.

Um diese Grundeinstellungen übersichtlich vorzunehmen, bitten wir Sie, Ihre Arbeitsumgebungen zu definieren und die
entsprechenden Pfade anzulegen. 

Bitte unterscheiden Sie zwischen den folgenden drei Arbeitsumgebungen und passen Sie für alle relevanten
Arbeitsumgebungen die Pfade an. 
Bitte löschen Sie nicht benötigte Pfade und ergänzen fehlende.

*	0: eigener Arbeitsplatz (z.B. Datenstrukturfile)
*	1: KDFV (Originaldatensatz)
*	2: GWAP (pseudonymisierte Originaldaten, ggf. ohne Bayern)
*/



* global FDZ 0
global FDZ 1 // Arbeitsumgebung bestimmen, hier auf KDFV gestellt (siehe oben)
* global FDZ 2



*	Anmerkung zur Definition der Arbeitsumgebung: 
*	Bitte ändern Sie die Namen der globals für die Zuweisung der Zielordner nicht. Benötigen Sie mehrere Zielordner
*	für einen Ergebnistyp, benennen Sie diese bitte nach folgendem Schema: global outputpfad-1, global outputpfad-2, ...
		
*	Arbeitsumgebung 0: Pfadangaben für die Arbeit am eigenen Arbeitsplatz (z.B. Datenstrukturfile)
*	-------------------------------------------------------------------------------------------------------------------

if $FDZ==0 {
	global datenpfad    "<eigener Arbeitsplatz Daten>" /* hier liegt z.B. das Datenstrukturfile */			   
	global outputpfad   "<eigener Arbeitsplatz Ergebnisse>" /* hier sollen alle Ergebnisse (inkl. log-file) gespeichert werden */
	global neudatenpfad "<eigener Arbeitsplatz Arbeitsdateien>" /* hier sollen neu erstellte Datensätze gespeichert werden */
	
	global dateiname "Name des Datensatzes einfügen.dta" /* z.B. Name des Datenstrukturfiles einfügen */
	global outputname "Name der logdatei einfügen" /* Name des log-files einfügen */
	
	adopath         + "<eigener Arbeitsplatz ado-Files>" /* Hier werden die benötigten ado-Files lokal abgespeichert */
}


*	Arbeitsumgebung 1: Pfadangaben für die Arbeit über die KDFV (Hinweis: die für Sie relevanten Pfade werden Ihnen in einer E-Mail bei Nutzungsbeginn mitgeteilt)
*	-------------------------------------------------------------------------------------------------------------------

if $FDZ==1 {
	global datenpfad    "Q:\Projektxxxx\Daten" /* hier liegen die Originaldaten */			   
	global outputpfad   "Q:\Projektxxxx\xxx" /* hier sollen alle Ergebnisse inkl. log-file) gespeichert werden */
	global neudatenpfad "Q:\Projektxxxx\xxx" /* hier sollen Arbeitsdateien gespeichert werden */
	
	global dateiname "Name des Datensatzes einfügen.dta" /* Name des Originaldatensatzes einfügen (siehe E-Mail) */
	global outputname "Name der logdatei einfügen" /* Name des log-files einfügen */

	adopath         + "Q:\stata\ado" /* Hier werden die benötigten ado-Files lokal abgespeichert */
}


*	Arbeitsumgebung 2: Pfadangaben für die Arbeit am GWAP(_formal)
*	-------------------------------------------------------------------------------------------------------------------

if $FDZ==2 {
	global datenpfad    "R:\Projektxxxx\Daten" /* hier liegen die Originaldaten */			   
	global outputpfad   "R:\Projektxxxx\xxx" /* hier sollen alle Ergebnisse inkl. log-file) gespeichert werden */
	global neudatenpfad "R:\Projektxxxx\xxx" /* hier sollen Arbeitsdateien gespeichert werden */
	
	global dateiname "Name des Datensatzes einfügen.dta" /* pseudonomisierte Originaldaten, ggf. ohne Bayern */
	global outputname "Name der logdatei einfügen"
	
	adopath         + "R:\stata\ado" /* Hier werden die benötigten ado-Files lokal abgespeichert */

}



*	-------------------------------------------------------------------------------------------------------------------
*	----
*	----	Block II: Bearbeitung der Daten
*	----
*	-------------------------------------------------------------------------------------------------------------------

*	Aufzeichnung in Protokoll starten
capture log close
log using "$outputpfad/${outputname}.log", replace





*	-------------------------------------------------------------------------------------------------------------------
/*
	Titel des Projekts: 			<Frauen und Arbeit in der Bundesrepublik>
	Datengrundlage: 				<Beispiel Mikrozensus 2012>
	
	Dateiname des Programmcodes: 	<syntaxname.do> // wenn verwendet, bitte auch die Version des Programmcodes angeben
	erstellt: 						<Datum> 
	von: 							<Name> 
	E-Mail: 						<E-Mail-Adresse> 
	Tel.: 							<Telefonnummer> 
	
	Dateiname des Output-Files: 	<outputname.log> 
	
	
	Grundriss des Programms: 
			<Programm zur Untersuchung von mehrfachen Personensätzen (Check der Datenbasis), 
	         deskriptive Analysen> 
	

	
	Verwendete Variablen (Beispieldatensatz hier: Mikrozensus 2012): 
	Originalvariablen: 	
			   <EF1:   	Land der Bundesrepublik 
				EF2:   	Regierungsbezirk 
				EF3:  	Auswahlbezirks-Nummer 
				EF4:  	systemfreie Lfd. Nr. d. Haushalts 
				EF5:  	systemfreie Lfd. Nr. d. Person im Haushalt
 				EF25:  	systemfreie Lfd. Nr. d. Familie im Haushalt
				EF30:  	Bevölkerung am Hauptwohnsitz
				EF31:  	Bevölkerung in Privathaushalten
				EF44:  	Alter
				EF46:  	Geschlecht 
				EF49:  	Familienstand
				EF310: 	Höchster allgemeiner Schulabschluss
	            EF952: 	Standardhochrechnungsfaktor Jahr (Basis: Zensus 2011)>
	
	
	Neu angelegte Variablen in dieser Syntax <syntaxname.sas>:  
			   <verh:       dichotome Variable Verheiratet ja/nein
	            persnr:  	Personennummer
				famnr:  	Familiennummer 
				hhnr:   	Haushaltsnummer
				nrdiff:  	Differenz Haushaltsnummer - Familiennummer 
				piddiff: 	Test einmalige Personennummer>
	
	Anmerkung: Falls Variablen verwendet werden, die in einer vorherigen Syntax erstellt wurden, 
	diese bitte in separaten Blöcken auflisten.   
	           
	Gewichtungsvariable: 	EF952
	
*/	
*	-------------------------------------------------------------------------------------------------------------------



*	-------------------------------------------------------------------------------------------------------------------
*	1. Datenaufbereitung
*	-------------------------------------------------------------------------------------------------------------------


*	a. Datensatz einlesen
*	Speicher- und laufzeiteffizient die Auswahl der benötigten Variablen und Fälle direkt vornehmen.

*	Bevölkerung in Privathaushalten (EF31 = 1) am Ort der Hauptwohnung (EF30 < 3)

use EF1 - EF5s EF25 EF30 EF31 EF44 EF46 EF49 EF310 EF952 ///
using "$DATADIR/${Datensatz}" if EF31 == 1 &  EF30 < 3, clear 

*	temporären Arbeitsdatensatz erstellen

save "$ARBEITSDIR/TEMP1.dta", replace // Dieser Datensatz wird nach der Analyse nicht mehr benötigt und kann am Ende gelöscht werden.
                                      // Besser als löschen: Temporäre Arbeitsdatensätze gar nicht erst abspeichern 


*	b. Generierung dichotome Variable verh, die angibt, ob Person verheiratet ist. 

recode EF49 (2 = 1) (1 3 4 5 6 7 = 0), gen (verh)

* 	Hilfestellung für Mikrozensusnutzer/-innen
*	c. Generierung Haushalts- und Familiennummer aus EF1, EF2, EF3, EF4, EF5, EF25 // 
*	persnr: EF1 bis EF5
*	hh: EF1 bis EF4s
*	famnr: EF1 bis EF4s + EF25

generate double persnr=(EF1*10000000000) + (EF2*1000000000) + (EF3*100000) + (EF4*1000) + (EF5*10)
generate double hhnr=(EF1*10000000000) + (EF2*1000000000) + (EF3*100000) + (EF4*1000) + 1
generate double famnr=(EF1*10000000000) + (EF2*1000000000) + (EF3*100000) + (EF4*1000) + (EF25*1)
format %13.0g persnr hhnr famnr


*	d. Vorbereitung Test: Haushaltsnummer ungleich Familiennummer
*	Wenn: Familiennummer (famnr) ungleich der Haushaltsnummer (hhnr)
*	Dann: Differenz Haushaltsnummer - Familiennummer (nrdiff) gleich 1

generate nrdiff = 0

replace nrdiff = 1 if famnr ~= hhnr


*	e. Vorbereitung Test: mehrfache Personennummer
*	Personennummer (persnr) gleich der des Vorgängers dann Personennummertest (piddiff) gleich 1 

sort persnr

generate piddiff = 0
replace piddiff = 1 if persnr == persnr[_n-1]


*	f. Beschriftung der Variablen und Werte

label variable verh     "Verheiratet"

label variable hhnr 	"Haushaltsnummer"
label variable famnr 	"Familiennummer"
label variable persnr 	"Personennummer"

label variable piddiff 	"Test einmalige Personennummer"
label variable nrdiff 	"Differenz Haushaltsnummer - Familiennummer"

label define verh       1 "ja" ///
                        0 "nein"
label values verh verh
						
label define nrdiffer 	1 "Haushaltsnummer und Familiennummer unterschiedlich" ///
						0 "Haushaltsnummer und Familiennummer gleich"
label values nrdiff nrdiffer

label define piddiffer 	1 "Personennummer mehrfach" ///
						0 "Personennummer einfach"
label values piddiff piddiffer

*	temporären Arbeitsdatensatz erstellen

save "$ARBEITSDIR/TEMP2.dta", replace // Dieser Datensatz wird nach der Analyse nicht mehr benötigt und kann am Ende gelöscht werden.

	
	
*	-------------------------------------------------------------------------------------------------------------------
*	2. Datenauswertung
*	-------------------------------------------------------------------------------------------------------------------

/*
	Für jedes erzeugte Ergebnis muss angegeben werden, ob es auf Geheimhaltung geprüft und freigegeben werden soll 
	oder ob es lediglich den Prüfprozessen der FDZ dient. Diese Angabe kann pauschal in einem Kommentar erfolgen, 
	beispielweise "Alle erzeugten Auswertungen werden benötigt." oder "Es werden ausschließlich gewichtete 
	Auswertungen benötigt.", solange die Formulierung eindeutig ist.

*/

*	Datenauswertung Gesamtdatensatz

*	Hinweis für das FDZ: die unter Punkt 2 erstellten Ergebnisse sollen nicht freigegeben werden.

*	Output Nr. 2.1: Haushaltsnummer ungleich Familiennummer

tabulate nrdiff


*	Output Nr. 2.2: Test mehrfache Personennummer

tabulate piddiff


*	Datenauswertung nach Variable verh

keep if verh == 1


*	Output Nr. 2.3: Haushaltsnummer ungleich Familiennummer

tabulate nrdiff


*	Output Nr. 2.4: Test mehrfache Personennummer

tabulate piddiff


*	TEMP2.dta aufrufen
use "$ARBEITSDIR\TEMP2.dta", clear



*	-------------------------------------------------------------------------------------------------------------------
*	3. gewichtete Auswertungen
*	-------------------------------------------------------------------------------------------------------------------

/*	
	Für die Geheimhaltungsprüfung ist es erforderlich, bei gewichteten Ausgaben zusätzlich auch 
	das ungewichtete Ergebnis mit ausgeben zu lassen (vgl. Broschüre 2.7 Ausgabe der zugrundeliegenden Fallzahlen
	und Kennzeichnung der Bezüge).
*/

*	Output Nr. 3.1: ungewichtete Häufigkeit des Bundeslandes

tabulate EF1


*	Output Nr. 3.2: gewichtete Häufigkeit des Bundeslandes

tabulate EF1 [iw = EF952]


*	Output Nr. 3.3: ungewichtete Regression mit der abhängigen Variablen Alter (EF44) und 
*	               den beiden unabhängigen Variablen Geschlecht (EF46) und Verheiratet (verh)

* Alternative a: Programmabbruch bei Fehlermeldung
reg EF44 EF46 verh

* Alternative b: Programm würde bei Stata-Fehlermeldung in der folgenden Zeile aufgrund des "capture noisily-Befehls" nicht abbrechen.
cap noi reg EF44 EF46 verh


*	Output Nr. 3.4: gewichtete Regression mit der abhängigen Variablen Alter (EF44) und 
*	               den beiden unabhängigen Variablen Geschlecht (EF46) und Verheiratet (verh)

reg EF44 EF46 verh [aweight = EF952]



*	-------------------------------------------------------------------------------------------------------------------
*	4. Auswertungen mit Filterbedingungen
*	-------------------------------------------------------------------------------------------------------------------

/*
	Restgrößen, die sich als Differenz zu "Insgesamt" erschließen, sind zu vermeiden.
	Beispiel: Sie erzeugen eine "Insgesamt"-Tabelle und eine Tabelle "Männlich".
	Die Restgröße/Differenz ist "Weiblich" und muss mit ausgegeben werden (vgl. Broschüre 2.9 Ausweis von Differenz-
	gruppen und Kennzeichnung der Bezüge sowie 3.2.4 Analyse von Teilpopulationen).
*/

*	Output Nr. 4.1: Häufigkeit des höchsten allgemeinen Schulabschlusses nach gesamt

tabulate EF310


*	Output Nr. 4.2: Häufigkeit des höchsten allgemeinen Schulabschlusses nach männlich

tabulate EF310 if EF46 == 1


*	Output Nr. 4.3: Häufigkeit des höchsten allgemeinen Schulabschlusses nach weiblich

tabulate EF310 if EF46 == 2 

/*
	Hinweis: Alternativ kann für diese Art der Auswertung auch eine Kreuztabelle ohne vorherige Fallauswahl 
	verwendet werden. Durch die Verwendung einer Kreuztabelle werden Restgrößen direkt vermieden.
*/



*	-------------------------------------------------------------------------------------------------------------------
*	5. Ausgabe deskriptiver Kennzahlen
*	-------------------------------------------------------------------------------------------------------------------

/*
	Aus Geheimhaltungsgründen sind Minima und Maxima metrischer Variablen zu unterdrücken (vgl. Broschüre 3.2.1
	Ausgabe von Einzelwerten). 
	Die Verwendung des tabulate-Befehls ist bei der Ausgabe von deskriptiven Kennzahlen zu vermeiden. Bitte 
	verwenden Sie den FDZ-tabstat-Befehl.
*/

*	Output Nr. 5.1: Anzahl, Mittelwert und Standardabweichung des Alters aller ledigen Personen (EF49==1)

*	Variante 1: Verwendung des tabstat-Befehls 

tabstat EF44 if EF49 == 1, statistics(n mean sd) // ACHTUNG: Filterung --> Restgruppen ausgeben lassen

*	Restgruppe mit ausgeben lassen
tabstat EF44 if EF49 != 1, statistics(n mean sd)

/*
	Variante 2: Verwendung des sum-Befehls
	Bei Verwendung des sum-Befehls ist ein Umschreiben des Sum-Befehls nötig. Die Verwendung der Option detail 
	ist zu vermeiden. Vorab muss das Ado-File "makematrix.ado" geladen werden.
*/

makematrix, from(r(N) r(mean) r(sd)): summarize EF44 if EF49 == 1 // ACHTUNG: Filterung --> Restgruppen ausgeben lassen

*	Restgruppe mit ausgeben lassen
makematrix, from(r(N) r(mean) r(sd)): summarize EF44 if EF49 != 1


/*
	Hinweis: Bei wirtschaftsstatistischen Daten sind bei der Ausgabe von deskriptiven Kennzahlen für die 
	Geheimhaltungsprüfung das Maximum, der zweitgrößte Wert und die Gesamtsumme der Variablen 
	(z.B. Umsatz, Einkünfte) mit auszugeben (vgl. Broschüre 3.1.3 Dominanzregeln und Faltblatt in der Broschüre).
*/

*	-------------------------------------------------------------------------------------------------------------------
*	6. Auswertungen von Dummy-Variablen 
*	-------------------------------------------------------------------------------------------------------------------

/*
	Zusätzlich zum Sum-Befehl ist die Häufigkeitstabelle auszugeben, da die Fallzahl der Merkmalsausprägung 
	für die Geheimhaltungsprüfung benötigt wird.
*/
 
*	Output Nr. 6.1:  Anzahl, Mittelwert und Standardabweichung des Geschlechts aller über 65-Jährigen (EF44 > 65)

summarize EF46 if EF44 > 65
*	für die Geheimhaltungsprüfung 
summarize EF46 if EF44 <= 65


*	Output Nr. 6.2  Häufigkeitsauszählung des Geschlechts aller über 65-Jährigen (EF44 > 65)

tabulate EF46 if EF44 > 65

*	für die Geheimhaltungsprüfung
tabulate EF46 if EF44 <= 65



*	-------------------------------------------------------------------------------------------------------------------
*	7. Ausgabe von Wertetabellen 
*	-------------------------------------------------------------------------------------------------------------------

/*
	Bei der Erstellung von Wertetabellen ist stets die zugrundeliegende Fallzahl mit anzugeben.
	
	Erstellen einer benutzerdefinierten Tabelle mit Anzahl, Mittelwert und gültige Häufigkeit (N) des Alters (EF44) 
	je Ausprägung Familienstand (EF49)
*/

*	Output Nr. 7.1: Kreuztabelle Alter und Familienstand

tabstat EF44, statistics(n mean count) by (EF49)


*	-------------------------------------------------------------------------------------------------------------------
*	----
*	----	Block III: Programmabschluss
*	----
*	-------------------------------------------------------------------------------------------------------------------

*	temporäre Dateien löschen
erase "$ARBEITSDIR\TEMP1.dta"
erase "$ARBEITSDIR\TEMP2.dta"

*	log- file schließen
log close

exit

*	-------------------------------------------------------------------------------------------------------------------
*	H I N W E I S:
/*
	Die vorliegende Mustersyntax stellt ein Beispiel für eine Erstsyntax dar. Wenn in den folgenden Syntaxen 
	Auswertungen gemacht werden, die einen inhaltlichen Bezug zu bereits erstellten Ergebnissen haben, sind die 
	Bezüge zu den entsprechenden vorherigen Syntaxen sowohl bei der Datenaufbereitung als auch bei der Auswertung in 
	einem Kommentar kenntlich zu machen.
*/
*	-------------------------------------------------------------------------------------------------------------------





